@@ -8,27 +8,27 @@ Paul Licameli split from TrackPanel.cpp
 
 **********************************************************************/
 
-#include "../../Audacity.h"
-#include "EnvelopeHandle.h"
 
-#include "../../Experimental.h"
+#include "EnvelopeHandle.h"
 
 #include "TrackView.h"
 
-#include "../../Envelope.h"
+#include "Envelope.h"
 #include "../../EnvelopeEditor.h"
 #include "../../HitTestResult.h"
 #include "../../prefs/WaveformSettings.h"
 #include "../../ProjectAudioIO.h"
-#include "../../ProjectHistory.h"
+#include "ProjectHistory.h"
 #include "../../RefreshCode.h"
 #include "../../TimeTrack.h"
-#include "../../TrackArtist.h"
+#include "../../TrackArt.h"
 #include "../../TrackPanelMouseEvent.h"
-#include "../../ViewInfo.h"
+#include "ViewInfo.h"
 #include "../../WaveTrack.h"
 #include "../../../images/Cursors.h"
 
+#include <wx/event.h>
+
 EnvelopeHandle::EnvelopeHandle( Envelope *pEnvelope )
    : mEnvelope{ pEnvelope }
 {
@@ -45,9 +45,9 @@ EnvelopeHandle::~EnvelopeHandle()
 {}
 
 UIHandlePtr EnvelopeHandle::HitAnywhere
-(std::weak_ptr<EnvelopeHandle> & WXUNUSED(holder), Envelope *envelope, bool timeTrack)
+(std::weak_ptr<EnvelopeHandle> &holder, Envelope *envelope, bool timeTrack)
 {
-   auto result = std::make_shared<EnvelopeHandle>( envelope );
+   auto result = AssignUIHandlePtr(holder, std::make_shared<EnvelopeHandle>(envelope));
    result->mTimeTrack = timeTrack;
    return result;
 }
@@ -93,7 +93,9 @@ UIHandlePtr EnvelopeHandle::WaveTrackHitTest
 {
    /// method that tells us if the mouse event landed on an
    /// envelope boundary.
-   Envelope *const envelope = wt->GetEnvelopeAtX(state.GetX());
+   auto &viewInfo = ViewInfo::Get(*pProject);
+   auto time = viewInfo.PositionToTime(state.m_x, rect.GetX());
+   Envelope *const envelope = wt->GetEnvelopeAtTime(time);
 
    if (!envelope)
       return {};
@@ -148,7 +150,9 @@ UIHandlePtr EnvelopeHandle::HitEnvelope
    // For amplification using the envelope we introduced the idea of contours.
    // The contours have the same shape as the envelope, which may be partially off-screen.
    // The contours are closer in to the center line.
-   int ContourSpacing = (int)(rect.height / (2 * (zoomMax - zoomMin)));
+   // Beware very short rectangles!  Make this at least 1
+   int ContourSpacing = std::max(1,
+      static_cast<int>(rect.height / (2 * (zoomMax - zoomMin))));
    const int MaxContours = 2;
 
    // Adding ContourSpacing/2 selects a region either side of the contour.
@@ -194,7 +198,9 @@ UIHandle::Result EnvelopeHandle::Click
                mEnvelopeEditors.push_back(
                   std::make_unique< EnvelopeEditor >( *mEnvelope, true ) );
             else {
-               auto e2 = channel->GetEnvelopeAtX(event.GetX());
+               auto time =
+                  viewInfo.PositionToTime(event.GetX(), evt.rect.GetX());
+               auto e2 = channel->GetEnvelopeAtTime(time);
                if (e2)
                   mEnvelopeEditors.push_back(
                      std::make_unique< EnvelopeEditor >( *e2, true ) );
